
# NETWORK_ANALYSIS

## Introduction

This usecase provides logs for workshops:
 1. Advanced Search Capabilities
 1. Statistical Search for Google SecOps

## Events

| Log Type     | Product Name | Vendor Name | Notes |
|--------------|--------------|-------------|-------|
| BRO_JSON     | Bro          | Zeek        |       |

## Entities

| Log Type | Product Name | Vendor Name | Notes |
|----------|--------------|-------------|-------|
| N/A      |              |             |       |

## Rules

| Rule Name         | Live  | Alerting | Notes |
|-------------------|-------|----------|-------|
| network_analysis  | False | False    |       |

## Saved Searches

| Search Name                 | Creator             | Notes |
|-----------------------------|---------------------|-------|
| Zeek_Investigative_Search.  | jstoner@google.com  |       |

## Reference Lists

| Reference List | Type   | Notes |
|----------------|--------|-------|
| N/A            |        |       |
